@@ -680,6 +680,7 @@ def get_soup(url, parser='html.parser', ignore_errs=True, **kwargs):
     try:
         rurl = normalize(url, True, True, True)
         with requests.get(rurl, **kwargs) as response:
+            # Screw weird ascii pages
             soup = BeautifulSoup(response.content, parser)
         return soup
     except Exception as e:
@@ -977,7 +978,9 @@ def write(file_name, contents='', force=False):
         else:
             raise InvalidFileError('"' + file_name + '" is not a file and cannot be written to. Use argument "force=True" to overwrite.')
     
-    if not isinstance(contents, str) and isinstance(contents, Iterable):
+    if isinstance(output, bytes):
+        output = contents.decode('utf-8')
+    elif not isinstance(contents, str) and isinstance(contents, Iterable):
         output = '\n'.join(contents)
     else:
         output = contents
